@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 FreeIPMI Core Team
+ * Copyright (C) 2003-2014 FreeIPMI Core Team
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include <string.h>
 #endif /* STDC_HEADERS */
 #include <errno.h>
+#include <assert.h>
 
 #include "freeipmi/cmds/ipmi-messaging-support-cmds.h"
 #include "freeipmi/fiid/fiid.h"
@@ -461,6 +462,69 @@ fiid_template_t tmpl_cmd_set_system_info_parameters_operating_system_name_rq =
     { 0, "", 0}
   };
 
+fiid_template_t tmpl_cmd_set_system_info_parameters_present_os_version_number_first_set_rq =
+  {
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "parameter_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "set_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "encoding", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "string_length", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 112, "string", FIID_FIELD_OPTIONAL | FIID_FIELD_LENGTH_VARIABLE},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_set_system_info_parameters_present_os_version_number_rq =
+  {
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "parameter_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "set_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 128, "string", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_VARIABLE},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_set_system_info_parameters_bmc_url_first_set_rq =
+  {
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "parameter_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "set_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "encoding", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "string_length", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 112, "string", FIID_FIELD_OPTIONAL | FIID_FIELD_LENGTH_VARIABLE},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_set_system_info_parameters_bmc_url_rq =
+  {
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "parameter_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "set_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 128, "string", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_VARIABLE},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_set_system_info_parameters_base_os_hypervisor_url_first_set_rq =
+  {
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "parameter_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "set_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "encoding", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "string_length", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 112, "string", FIID_FIELD_OPTIONAL | FIID_FIELD_LENGTH_VARIABLE},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_set_system_info_parameters_base_os_hypervisor_url_rq =
+  {
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "parameter_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "set_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 128, "string", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_VARIABLE},
+    { 0, "", 0}
+  };
+
 fiid_template_t tmpl_cmd_get_system_info_parameters_rq =
   {
     { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
@@ -583,6 +647,75 @@ fiid_template_t tmpl_cmd_get_system_info_parameters_operating_system_name_rs =
     { 0, "", 0}
   };
 
+fiid_template_t tmpl_cmd_get_system_info_parameters_present_os_version_number_first_set_rs =
+  {
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "comp_code", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "parameter_revision", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "set_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "encoding", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "string_length", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 112, "string", FIID_FIELD_OPTIONAL | FIID_FIELD_LENGTH_VARIABLE},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_get_system_info_parameters_present_os_version_number_rs =
+  {
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "comp_code", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "parameter_revision", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "set_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 128, "string", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_VARIABLE},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_get_system_info_parameters_bmc_url_first_set_rs =
+  {
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "comp_code", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "parameter_revision", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "set_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "encoding", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "string_length", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 112, "string", FIID_FIELD_OPTIONAL | FIID_FIELD_LENGTH_VARIABLE},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_get_system_info_parameters_bmc_url_rs =
+  {
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "comp_code", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "parameter_revision", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "set_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 128, "string", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_VARIABLE},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_get_system_info_parameters_base_os_hypervisor_url_first_set_rs =
+  {
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "comp_code", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "parameter_revision", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "set_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "encoding", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 4, "reserved", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "string_length", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 112, "string", FIID_FIELD_OPTIONAL | FIID_FIELD_LENGTH_VARIABLE},
+    { 0, "", 0}
+  };
+
+fiid_template_t tmpl_cmd_get_system_info_parameters_base_os_hypervisor_url_rs =
+  {
+    { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "comp_code", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED | FIID_FIELD_MAKES_PACKET_SUFFICIENT},
+    { 8, "parameter_revision", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 8, "set_selector", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
+    { 128, "string", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_VARIABLE},
+    { 0, "", 0}
+  };
+
 fiid_template_t tmpl_cmd_get_channel_cipher_suites_rq =
   {
     { 8, "cmd", FIID_FIELD_REQUIRED | FIID_FIELD_LENGTH_FIXED},
@@ -1308,16 +1441,20 @@ fill_cmd_set_system_info_parameters_set_in_progress (uint8_t state,
   return (0);
 }
 
-int
-fill_cmd_set_system_info_parameters_system_firmware_version_first_set (uint8_t set_selector,
-                                                                       uint8_t encoding,
-                                                                       uint8_t string_length,
-                                                                       const void *string_block,
-                                                                       unsigned int string_block_length,
-                                                                       fiid_obj_t obj_cmd_rq)
+static int
+_fill_cmd_set_system_info_parameters_string_first_set_common (uint8_t set_selector,
+							      uint8_t encoding,
+							      uint8_t string_length,
+							      const void *string_block,
+							      unsigned int string_block_length,
+							      fiid_obj_t obj_cmd_rq,
+							      fiid_field_t *tmpl_cmd_rq_expected,
+							      uint8_t parameter_selector)
 {
   uint8_t stringbuf[IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX];
 
+  assert (tmpl_cmd_rq_expected);
+
   if (!IPMI_SYSTEM_INFO_ENCODING_VALID (encoding)
       || string_block_length > IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX
       || !fiid_obj_valid (obj_cmd_rq))
@@ -1326,7 +1463,7 @@ fill_cmd_set_system_info_parameters_system_firmware_version_first_set (uint8_t s
       return (-1);
     }
 
-  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_set_system_info_parameters_system_firmware_version_first_set_rq) < 0)
+  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_rq_expected) < 0)
     {
       ERRNO_TRACE (errno);
       return (-1);
@@ -1334,7 +1471,7 @@ fill_cmd_set_system_info_parameters_system_firmware_version_first_set (uint8_t s
 
   FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_SET_SYSTEM_INFO_PARAMETERS);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "parameter_selector", IPMI_SYSTEM_INFO_PARAMETER_SYSTEM_FIRMWARE_VERSION);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "parameter_selector", parameter_selector);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "set_selector", set_selector);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "encoding", encoding);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved", 0);
@@ -1351,14 +1488,18 @@ fill_cmd_set_system_info_parameters_system_firmware_version_first_set (uint8_t s
   return (0);
 }
 
-int
-fill_cmd_set_system_info_parameters_system_firmware_version (uint8_t set_selector,
-                                                             const void *string_block,
-                                                             unsigned int string_block_length,
-                                                             fiid_obj_t obj_cmd_rq)
+static int
+_fill_cmd_set_system_info_parameters_string_set_common (uint8_t set_selector,
+							const void *string_block,
+							unsigned int string_block_length,
+							fiid_obj_t obj_cmd_rq,
+							fiid_field_t *tmpl_cmd_rq_expected,
+							uint8_t parameter_selector)
 {
   uint8_t stringbuf[IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX];
 
+  assert (tmpl_cmd_rq_expected);
+
   if (string_block_length > IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX
       || !fiid_obj_valid (obj_cmd_rq))
     {
@@ -1366,17 +1507,17 @@ fill_cmd_set_system_info_parameters_system_firmware_version (uint8_t set_selecto
       return (-1);
     }
 
-  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_set_system_info_parameters_system_firmware_version_rq) < 0)
+  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_rq_expected) < 0)
     {
       ERRNO_TRACE (errno);
       return (-1);
     }
-
+    
   FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_SET_SYSTEM_INFO_PARAMETERS);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "parameter_selector", IPMI_SYSTEM_INFO_PARAMETER_SYSTEM_FIRMWARE_VERSION);
+  FILL_FIID_OBJ_SET (obj_cmd_rq, "parameter_selector", parameter_selector);
   FILL_FIID_OBJ_SET (obj_cmd_rq, "set_selector", set_selector);
-
+   
   /* achu: spec is not clear if this data should be 0 extended, we
    * will do it to be on the safe side
    */
@@ -1384,6 +1525,50 @@ fill_cmd_set_system_info_parameters_system_firmware_version (uint8_t set_selecto
   if (string_block && string_block_length)
     memcpy (stringbuf, string_block, string_block_length);
   FILL_FIID_OBJ_SET_DATA (obj_cmd_rq, "string", stringbuf, IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX);
+   
+  return (0);
+}
+
+int
+fill_cmd_set_system_info_parameters_system_firmware_version_first_set (uint8_t set_selector,
+                                                                       uint8_t encoding,
+                                                                       uint8_t string_length,
+                                                                       const void *string_block,
+                                                                       unsigned int string_block_length,
+                                                                       fiid_obj_t obj_cmd_rq)
+{
+  if (_fill_cmd_set_system_info_parameters_string_first_set_common (set_selector,
+								    encoding,
+								    string_length,
+								    string_block,
+								    string_block_length,
+								    obj_cmd_rq,
+								    tmpl_cmd_set_system_info_parameters_system_firmware_version_first_set_rq,
+								    IPMI_SYSTEM_INFO_PARAMETER_SYSTEM_FIRMWARE_VERSION) < 0)
+    {
+      ERRNO_TRACE (errno);
+      return (-1);
+    }
+
+  return (0);
+}
+
+int
+fill_cmd_set_system_info_parameters_system_firmware_version (uint8_t set_selector,
+                                                             const void *string_block,
+                                                             unsigned int string_block_length,
+                                                             fiid_obj_t obj_cmd_rq)
+{
+  if (_fill_cmd_set_system_info_parameters_string_set_common (set_selector,
+							      string_block,
+							      string_block_length,
+							      obj_cmd_rq,
+							      tmpl_cmd_set_system_info_parameters_system_firmware_version_rq,
+							      IPMI_SYSTEM_INFO_PARAMETER_SYSTEM_FIRMWARE_VERSION) < 0)
+    {
+      ERRNO_TRACE (errno);
+      return (-1);
+    }
 
   return (0);
 }
@@ -1396,38 +1581,19 @@ fill_cmd_set_system_info_parameters_system_name_first_set (uint8_t set_selector,
                                                            unsigned int string_block_length,
                                                            fiid_obj_t obj_cmd_rq)
 {
-  uint8_t stringbuf[IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX];
-
-  if (!IPMI_SYSTEM_INFO_ENCODING_VALID (encoding)
-      || string_block_length > IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX
-      || !fiid_obj_valid (obj_cmd_rq))
-    {
-      SET_ERRNO (EINVAL);
-      return (-1);
-    }
-
-  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_set_system_info_parameters_system_name_first_set_rq) < 0)
+  if (_fill_cmd_set_system_info_parameters_string_first_set_common (set_selector,
+								    encoding,
+								    string_length,
+								    string_block,
+								    string_block_length,
+								    obj_cmd_rq,
+								    tmpl_cmd_set_system_info_parameters_system_name_first_set_rq,
+								    IPMI_SYSTEM_INFO_PARAMETER_SYSTEM_NAME) < 0)
     {
       ERRNO_TRACE (errno);
       return (-1);
     }
 
-  FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_SET_SYSTEM_INFO_PARAMETERS);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "parameter_selector", IPMI_SYSTEM_INFO_PARAMETER_SYSTEM_NAME);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "set_selector", set_selector);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "encoding", encoding);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved", 0);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "string_length", string_length);
-
-  /* achu: spec is not clear if this data should be 0 extended, we
-   * will do it to be on the safe side
-   */
-  memset (stringbuf, '\0', IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX);
-  if (string_block && string_block_length)
-    memcpy (stringbuf, string_block, string_block_length);
-  FILL_FIID_OBJ_SET_DATA (obj_cmd_rq, "string", stringbuf, IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX);
-
   return (0);
 }
   
@@ -1437,34 +1603,17 @@ fill_cmd_set_system_info_parameters_system_name (uint8_t set_selector,
                                                  unsigned int string_block_length,
                                                  fiid_obj_t obj_cmd_rq)
 {
-  uint8_t stringbuf[IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX];
-
-  if (string_block_length > IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX
-      || !fiid_obj_valid (obj_cmd_rq))
-    {
-      SET_ERRNO (EINVAL);
-      return (-1);
-    }
-
-  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_set_system_info_parameters_system_name_rq) < 0)
+  if (_fill_cmd_set_system_info_parameters_string_set_common (set_selector,
+							      string_block,
+							      string_block_length,
+							      obj_cmd_rq,
+							      tmpl_cmd_set_system_info_parameters_system_name_rq,
+							      IPMI_SYSTEM_INFO_PARAMETER_SYSTEM_NAME) < 0)
     {
       ERRNO_TRACE (errno);
       return (-1);
     }
 
-  FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_SET_SYSTEM_INFO_PARAMETERS);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "parameter_selector", IPMI_SYSTEM_INFO_PARAMETER_SYSTEM_NAME);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "set_selector", set_selector);
-
-  /* achu: spec is not clear if this data should be 0 extended, we
-   * will do it to be on the safe side
-   */
-  memset (stringbuf, '\0', IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX);
-  if (string_block && string_block_length)
-    memcpy (stringbuf, string_block, string_block_length);
-  FILL_FIID_OBJ_SET_DATA (obj_cmd_rq, "string", stringbuf, IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX);
-
   return (0);
 }
 
@@ -1476,38 +1625,19 @@ fill_cmd_set_system_info_parameters_primary_operating_system_name_first_set (uin
                                                                              unsigned int string_block_length,
                                                                              fiid_obj_t obj_cmd_rq)
 {
-  uint8_t stringbuf[IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX];
-
-  if (!IPMI_SYSTEM_INFO_ENCODING_VALID (encoding)
-      || string_block_length > IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX
-      || !fiid_obj_valid (obj_cmd_rq))
-    {
-      SET_ERRNO (EINVAL);
-      return (-1);
-    }
-
-  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_set_system_info_parameters_primary_operating_system_name_first_set_rq) < 0)
+  if (_fill_cmd_set_system_info_parameters_string_first_set_common (set_selector,
+								    encoding,
+								    string_length,
+								    string_block,
+								    string_block_length,
+								    obj_cmd_rq,
+								    tmpl_cmd_set_system_info_parameters_primary_operating_system_name_first_set_rq,
+								    IPMI_SYSTEM_INFO_PARAMETER_PRIMARY_OPERATING_SYSTEM_NAME) < 0)
     {
       ERRNO_TRACE (errno);
       return (-1);
     }
 
-  FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_SET_SYSTEM_INFO_PARAMETERS);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "parameter_selector", IPMI_SYSTEM_INFO_PARAMETER_PRIMARY_OPERATING_SYSTEM_NAME);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "set_selector", set_selector);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "encoding", encoding);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved", 0);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "string_length", string_length);
-
-  /* achu: spec is not clear if this data should be 0 extended, we
-   * will do it to be on the safe side
-   */
-  memset (stringbuf, '\0', IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX);
-  if (string_block && string_block_length)
-    memcpy (stringbuf, string_block, string_block_length);
-  FILL_FIID_OBJ_SET_DATA (obj_cmd_rq, "string", stringbuf, IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX);
-
   return (0);
 }
 
@@ -1517,34 +1647,17 @@ fill_cmd_set_system_info_parameters_primary_operating_system_name (uint8_t set_s
                                                                    unsigned int string_block_length,
                                                                    fiid_obj_t obj_cmd_rq)
 {
-  uint8_t stringbuf[IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX];
-
-  if (string_block_length > IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX
-      || !fiid_obj_valid (obj_cmd_rq))
-    {
-      SET_ERRNO (EINVAL);
-      return (-1);
-    }
-
-  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_set_system_info_parameters_primary_operating_system_name_rq) < 0)
+  if (_fill_cmd_set_system_info_parameters_string_set_common (set_selector,
+							      string_block,
+							      string_block_length,
+							      obj_cmd_rq,
+							      tmpl_cmd_set_system_info_parameters_primary_operating_system_name_rq,
+							      IPMI_SYSTEM_INFO_PARAMETER_PRIMARY_OPERATING_SYSTEM_NAME) < 0)
     {
       ERRNO_TRACE (errno);
       return (-1);
     }
 
-  FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_SET_SYSTEM_INFO_PARAMETERS);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "parameter_selector", IPMI_SYSTEM_INFO_PARAMETER_PRIMARY_OPERATING_SYSTEM_NAME);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "set_selector", set_selector);
-
-  /* achu: spec is not clear if this data should be 0 extended, we
-   * will do it to be on the safe side
-   */
-  memset (stringbuf, '\0', IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX);
-  if (string_block && string_block_length)
-    memcpy (stringbuf, string_block, string_block_length);
-  FILL_FIID_OBJ_SET_DATA (obj_cmd_rq, "string", stringbuf, IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX);
-
   return (0);
 }
 
@@ -1556,38 +1669,19 @@ fill_cmd_set_system_info_parameters_operating_system_name_first_set (uint8_t set
                                                                      unsigned int string_block_length,
                                                                      fiid_obj_t obj_cmd_rq)
 {
-  uint8_t stringbuf[IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX];
-
-  if (!IPMI_SYSTEM_INFO_ENCODING_VALID (encoding)
-      || string_block_length > IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX
-      || !fiid_obj_valid (obj_cmd_rq))
-    {
-      SET_ERRNO (EINVAL);
-      return (-1);
-    }
-
-  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_set_system_info_parameters_operating_system_name_first_set_rq) < 0)
+  if (_fill_cmd_set_system_info_parameters_string_first_set_common (set_selector,
+								    encoding,
+								    string_length,
+								    string_block,
+								    string_block_length,
+								    obj_cmd_rq,
+								    tmpl_cmd_set_system_info_parameters_operating_system_name_first_set_rq,
+								    IPMI_SYSTEM_INFO_PARAMETER_OPERATING_SYSTEM_NAME) < 0)
     {
       ERRNO_TRACE (errno);
       return (-1);
     }
 
-  FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_SET_SYSTEM_INFO_PARAMETERS);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "parameter_selector", IPMI_SYSTEM_INFO_PARAMETER_OPERATING_SYSTEM_NAME);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "set_selector", set_selector);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "encoding", encoding);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "reserved", 0);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "string_length", string_length);
-
-  /* achu: spec is not clear if this data should be 0 extended, we
-   * will do it to be on the safe side
-   */
-  memset (stringbuf, '\0', IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX);
-  if (string_block && string_block_length)
-    memcpy (stringbuf, string_block, string_block_length);
-  FILL_FIID_OBJ_SET_DATA (obj_cmd_rq, "string", stringbuf, IPMI_SYSTEM_INFO_FIRST_SET_STRING_LEN_MAX);
-
   return (0);
 }
 
@@ -1597,33 +1691,148 @@ fill_cmd_set_system_info_parameters_operating_system_name (uint8_t set_selector,
                                                            unsigned int string_block_length,
                                                            fiid_obj_t obj_cmd_rq)
 {
-  uint8_t stringbuf[IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX];
-
-  if (string_block_length > IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX
-      || !fiid_obj_valid (obj_cmd_rq))
-    {
-      SET_ERRNO (EINVAL);
-      return (-1);
-    }
-
-  if (FIID_OBJ_TEMPLATE_COMPARE (obj_cmd_rq, tmpl_cmd_set_system_info_parameters_operating_system_name_rq) < 0)
+  if (_fill_cmd_set_system_info_parameters_string_set_common (set_selector,
+							      string_block,
+							      string_block_length,
+							      obj_cmd_rq,
+							      tmpl_cmd_set_system_info_parameters_operating_system_name_rq,
+							      IPMI_SYSTEM_INFO_PARAMETER_OPERATING_SYSTEM_NAME) < 0)
     {
       ERRNO_TRACE (errno);
       return (-1);
     }
 
-  FILL_FIID_OBJ_CLEAR (obj_cmd_rq);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "cmd", IPMI_CMD_SET_SYSTEM_INFO_PARAMETERS);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "parameter_selector", IPMI_SYSTEM_INFO_PARAMETER_OPERATING_SYSTEM_NAME);
-  FILL_FIID_OBJ_SET (obj_cmd_rq, "set_selector", set_selector);
+  return (0);
+}
 
-  /* achu: spec is not clear if this data should be 0 extended, we
-   * will do it to be on the safe side
-   */
-  memset (stringbuf, '\0', IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX);
-  if (string_block && string_block_length)
-    memcpy (stringbuf, string_block, string_block_length);
-  FILL_FIID_OBJ_SET_DATA (obj_cmd_rq, "string", stringbuf, IPMI_SYSTEM_INFO_SET_STRING_LEN_MAX);
+int
+fill_cmd_set_system_info_parameters_present_os_version_number_first_set (uint8_t set_selector,
+									 uint8_t encoding,
+									 uint8_t string_length,
+									 const void *string_block,
+									 unsigned int string_block_length,
+									 fiid_obj_t obj_cmd_rq)
+{
+  if (_fill_cmd_set_system_info_parameters_string_first_set_common (set_selector,
+								    encoding,
+								    string_length,
+								    string_block,
+								    string_block_length,
+								    obj_cmd_rq,
+								    tmpl_cmd_set_system_info_parameters_present_os_version_number_first_set_rq,
+								    IPMI_SYSTEM_INFO_PARAMETER_PRESENT_OS_VERSION_NUMBER) < 0)
+    {
+      ERRNO_TRACE (errno);
+      return (-1);
+    }
+
+  return (0);
+}
+
+int
+fill_cmd_set_system_info_parameters_present_os_version_number (uint8_t set_selector,
+							       const void *string_block,
+							       unsigned int string_block_length,
+							       fiid_obj_t obj_cmd_rq)
+{
+  if (_fill_cmd_set_system_info_parameters_string_set_common (set_selector,
+							      string_block,
+							      string_block_length,
+							      obj_cmd_rq,
+							      tmpl_cmd_set_system_info_parameters_present_os_version_number_rq,
+							      IPMI_SYSTEM_INFO_PARAMETER_PRESENT_OS_VERSION_NUMBER) < 0)
+    {
+      ERRNO_TRACE (errno);
+      return (-1);
+    }
+
+  return (0);
+}
+
+int
+fill_cmd_set_system_info_parameters_bmc_url_first_set (uint8_t set_selector,
+						       uint8_t encoding,
+						       uint8_t string_length,
+						       const void *string_block,
+						       unsigned int string_block_length,
+						       fiid_obj_t obj_cmd_rq)
+{
+  if (_fill_cmd_set_system_info_parameters_string_first_set_common (set_selector,
+								    encoding,
+								    string_length,
+								    string_block,
+								    string_block_length,
+								    obj_cmd_rq,
+								    tmpl_cmd_set_system_info_parameters_bmc_url_first_set_rq,
+								    IPMI_SYSTEM_INFO_PARAMETER_BMC_URL) < 0)
+    {
+      ERRNO_TRACE (errno);
+      return (-1);
+    }
+
+  return (0);
+}
+
+int
+fill_cmd_set_system_info_parameters_bmc_url (uint8_t set_selector,
+					     const void *string_block,
+					     unsigned int string_block_length,
+					     fiid_obj_t obj_cmd_rq)
+{
+  if (_fill_cmd_set_system_info_parameters_string_set_common (set_selector,
+							      string_block,
+							      string_block_length,
+							      obj_cmd_rq,
+							      tmpl_cmd_set_system_info_parameters_bmc_url_rq,
+							      IPMI_SYSTEM_INFO_PARAMETER_BMC_URL) < 0)
+    {
+      ERRNO_TRACE (errno);
+      return (-1);
+    }
+
+  return (0);
+}
+
+int
+fill_cmd_set_system_info_parameters_base_os_hypervisor_url_first_set (uint8_t set_selector,
+								      uint8_t encoding,
+								      uint8_t string_length,
+								      const void *string_block,
+								      unsigned int string_block_length,
+								      fiid_obj_t obj_cmd_rq)
+{
+  if (_fill_cmd_set_system_info_parameters_string_first_set_common (set_selector,
+								    encoding,
+								    string_length,
+								    string_block,
+								    string_block_length,
+								    obj_cmd_rq,
+								    tmpl_cmd_set_system_info_parameters_base_os_hypervisor_url_first_set_rq,
+								    IPMI_SYSTEM_INFO_PARAMETER_BASE_OS_HYPERVISOR_URL) < 0)
+    {
+      ERRNO_TRACE (errno);
+      return (-1);
+    }
+
+  return (0);
+}
+
+int
+fill_cmd_set_system_info_parameters_base_os_hypervisor_url (uint8_t set_selector,
+							    const void *string_block,
+							    unsigned int string_block_length,
+							    fiid_obj_t obj_cmd_rq)
+{
+  if (_fill_cmd_set_system_info_parameters_string_set_common (set_selector,
+							      string_block,
+							      string_block_length,
+							      obj_cmd_rq,
+							      tmpl_cmd_set_system_info_parameters_base_os_hypervisor_url_rq,
+							      IPMI_SYSTEM_INFO_PARAMETER_BASE_OS_HYPERVISOR_URL) < 0)
+    {
+      ERRNO_TRACE (errno);
+      return (-1);
+    }
 
   return (0);
 }
