@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 FreeIPMI Core Team
+ * Copyright (C) 2003-2014 FreeIPMI Core Team
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -143,6 +143,8 @@ extern "C" {
 
 #define IPMI_INTEL_PRODUCT_ID_S5000PAL 40
 
+#define IPMI_INTEL_PRODUCT_ID_WINDMILL 2818
+
 /* 
  * Intel derived
  */
@@ -155,6 +157,10 @@ extern "C" {
 
 #define IPMI_APPRO_PRODUCT_ID_QG812X_CN IPMI_INTEL_PRODUCT_ID_QUANTA_QSSC_S4R
 
+#define IPMI_QUANTA_PRODUCT_ID_WINTERFELL IPMI_INTEL_PRODUCT_ID_WINDMILL
+
+#define IPMI_WIWYNN_PRODUCT_ID_WINDMILL IPMI_INTEL_PRODUCT_ID_WINDMILL
+
 /*******************************************
  * IBM                                     *
  *******************************************/
