@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 FreeIPMI Core Team
+ * Copyright (C) 2003-2014 FreeIPMI Core Team
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -217,6 +217,7 @@ extern unsigned int ipmi_generic_event_reading_type_code_acpi_power_state_short_
 #define IPMI_SENSOR_TYPE_POWER_SUPPLY_POWER_SUPPLY_INPUT_LOST_OR_OUT_OF_RANGE     0x04
 #define IPMI_SENSOR_TYPE_POWER_SUPPLY_POWER_SUPPLY_INPUT_OUT_OF_RANGE_BUT_PRESENT 0x05
 #define IPMI_SENSOR_TYPE_POWER_SUPPLY_CONFIGURATION_ERROR                         0x06
+#define IPMI_SENSOR_TYPE_POWER_SUPPLY_POWER_SUPPLY_INACTIVE                       0x07
 
 #define IPMI_SENSOR_TYPE_POWER_SUPPLY_EVENT_DATA3_OFFSET_CONFIGURATION_ERROR_ERROR_TYPE_VENDOR_MISMATCH              0x00
 #define IPMI_SENSOR_TYPE_POWER_SUPPLY_EVENT_DATA3_OFFSET_CONFIGURATION_ERROR_ERROR_TYPE_REVISION_MISMATCH            0x01
@@ -466,13 +467,17 @@ extern unsigned int ipmi_generic_event_reading_type_code_acpi_power_state_short_
 #define IPMI_SENSOR_TYPE_BOOT_ERROR_INVALID_BOOT_SECTOR                               0x03
 #define IPMI_SENSOR_TYPE_BOOT_ERROR_TIMEOUT_WAITING_FOR_USER_SELECTION_OF_BOOT_SOURCE 0x04
 
-#define IPMI_SENSOR_TYPE_OS_BOOT_A_BOOT_COMPLETED                         0x00
-#define IPMI_SENSOR_TYPE_OS_BOOT_C_BOOT_COMPLETED                         0x01
-#define IPMI_SENSOR_TYPE_OS_BOOT_PXE_BOOT_COMPLETED                       0x02
-#define IPMI_SENSOR_TYPE_OS_BOOT_DIAGNOSTIC_BOOT_COMPLETED                0x03
-#define IPMI_SENSOR_TYPE_OS_BOOT_CD_ROM_BOOT_COMPLETED                    0x04
-#define IPMI_SENSOR_TYPE_OS_BOOT_ROM_BOOT_COMPLETED                       0x05
-#define IPMI_SENSOR_TYPE_OS_BOOT_BOOT_COMPLETED_BOOT_DEVICE_NOT_SPECIFIED 0x06
+#define IPMI_SENSOR_TYPE_OS_BOOT_A_BOOT_COMPLETED                          0x00
+#define IPMI_SENSOR_TYPE_OS_BOOT_C_BOOT_COMPLETED                          0x01
+#define IPMI_SENSOR_TYPE_OS_BOOT_PXE_BOOT_COMPLETED                        0x02
+#define IPMI_SENSOR_TYPE_OS_BOOT_DIAGNOSTIC_BOOT_COMPLETED                 0x03
+#define IPMI_SENSOR_TYPE_OS_BOOT_CD_ROM_BOOT_COMPLETED                     0x04
+#define IPMI_SENSOR_TYPE_OS_BOOT_ROM_BOOT_COMPLETED                        0x05
+#define IPMI_SENSOR_TYPE_OS_BOOT_BOOT_COMPLETED_BOOT_DEVICE_NOT_SPECIFIED  0x06
+#define IPMI_SENSOR_TYPE_OS_BOOT_BASE_OS_HYPERVISOR_INSTALLATION_STARTED   0x07
+#define IPMI_SENSOR_TYPE_OS_BOOT_BASE_OS_HYPERVISOR_INSTALLATION_COMPLETED 0x08
+#define IPMI_SENSOR_TYPE_OS_BOOT_BASE_OS_HYPERVISOR_INSTALLATION_ABORTED   0x09
+#define IPMI_SENSOR_TYPE_OS_BOOT_BASE_OS_HYPERVISOR_INSTALLATION_FAILED    0x0A
 
 #define IPMI_SENSOR_TYPE_OS_CRITICAL_STOP_CRITICAL_STOP_DURING_OS_LOAD   0x00
 #define IPMI_SENSOR_TYPE_OS_CRITICAL_STOP_RUN_TIME_CRITICAL_STOP         0x01
