@@ -1,7 +1,7 @@
 /*****************************************************************************\
  *  $Id: ipmiconsole_defs.h,v 1.80 2010-06-10 22:10:12 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007-2013 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2014 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -217,6 +217,8 @@ typedef enum
    | IPMICONSOLE_WORKAROUND_OPEN_SESSION_PRIVILEGE          \
    | IPMICONSOLE_WORKAROUND_NON_EMPTY_INTEGRITY_CHECK_VALUE \
    | IPMICONSOLE_WORKAROUND_NO_CHECKSUM_CHECK               \
+   | IPMICONSOLE_WORKAROUND_SERIAL_ALERTS_DEFERRED          \
+   | IPMICONSOLE_WORKAROUND_INCREMENT_SOL_PACKET_SEQUENCE   \
    | IPMICONSOLE_WORKAROUND_IGNORE_SOL_PAYLOAD_SIZE         \
    | IPMICONSOLE_WORKAROUND_IGNORE_SOL_PORT                 \
    | IPMICONSOLE_WORKAROUND_SKIP_SOL_ACTIVATION_STATUS      \
@@ -374,6 +376,7 @@ struct ipmiconsole_ctx_session {
    * Protocol Maintenance Variables
    */
   unsigned int retransmission_count;
+  unsigned int workaround_retransmission_count; /* For IPMICONSOLE_WORKAROUND_INCREMENT_SOL_PACKET_SEQUENCE */
   unsigned int errors_count;
   unsigned int session_sequence_number_errors_count;
   unsigned int activate_payloads_count;
